"use strict";(self.webpackChunkhiglass_widget=self.webpackChunkhiglass_widget||[]).push([[879],{326:(e,i,s)=>{s.r(i),s.d(i,{default:()=>d});var t=s(728),o=s(203),l=s(147);s(995);const d={id:`${l.u2}:plugin`,requires:[t.IJupyterWidgetRegistry],activate:(e,i)=>{let s=(0,o.Z)(t);i.registerWidget({name:l.u2,version:l.i8,exports:s})},autoStart:!0}},203:(e,i,s)=>{s.d(i,{Z:()=>d});var t=s(107),o=s(147);function l({xDomain:e,yDomain:i}){let[s,t]=e,[o,l]=i;return[s,t,o,l]}function d(e){class i extends e.DOMWidgetModel{defaults(){return{...super.defaults(),_model_name:i.model_name,_model_module:i.model_module,_model_module_version:i.model_module_version,_view_name:s.view_name,_view_module:s.view_module,_view_module_version:s.view_module_version}}static model_name="HiGlassModel";static model_module=o.u2;static model_module_version=o.i8;static view_name="HiGlassView";static view_module=o.u2;static view_module_version=o.i8}class s extends e.DOMWidgetView{async render(){let e=JSON.parse(this.model.get("_viewconf")),i=await t.viewer(this.el,e);this.model.on("msg:custom",(e=>{e=JSON.parse(e);let[s,...t]=e;i[s](...t)})),1===e.views.length?i.on("location",(e=>{this.model.set("location",l(e)),this.model.save_changes()}),e.views[0].uid):e.views.forEach(((e,s)=>{i.on("location",(e=>{let i=this.model.get("location").slice();i[s]=l(e),this.model.set("location",i),this.model.save_changes()}),e.uid)}))}}return{HiGlassModel:i,HiGlassView:s}}},912:e=>{e.exports="data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHN0eWxlPSJiYWNrZ3JvdW5kLWNvbG9yOiNmZmZmZmYwMCIgd2lkdGg9IjYiIGhlaWdodD0iNiI+PHBhdGggZD0iTTYgNkgwVjQuMmg0LjJWMEg2djZ6IiBvcGFjaXR5PSIuMzAyIi8+PC9zdmc+"},147:e=>{e.exports=JSON.parse('{"u2":"higlass-widget","i8":"0.0.3"}')}}]);